Struct lsblk::BlockDevice

source ·
pub struct BlockDevice {
    pub name: String,
    pub fullname: PathBuf,
    pub diskseq: Option<String>,
    pub path: Option<String>,
    pub uuid: Option<String>,
    pub partuuid: Option<String>,
    pub label: Option<String>,
    pub partlabel: Option<String>,
    pub id: Option<String>,
}
A representation of a block-device

Fields

name: String

the filename of the block-device.

fullname: PathBuf

The full name of the block-device, which is basically /dev/{name}.

diskseq: Option<String>

The diskseq of the device as in /dev/disk/by-diskseq/.

path: Option<String>

The path (not the filesystem!) of the device as in /dev/disk/by-path.

uuid: Option<String>

The device UUID.

partuuid: Option<String>

The UUID of a partition (not the same as device UUID).

label: Option<String>

The label of the partition.

partlabel: Option<String>

The partition label (not the same as label), as in /dev/disk/by-partlabel)

id: Option<String>

The id of the device as in /dev/disk/by-id/.

Implementations

source

impl BlockDevice

source

pub fn list() -> Result<Vec<Self>, LsblkError>

List out all found block devices and populate all fields.

Panics

If somehow there exists a device that isn’t in /dev/, the function panics.

Errors

There are no particular errors other than IO / symlink resolution failures, etc.

source

pub const fn is_disk(&self) -> bool

Returns true if and only if the device is a storage disk and is not a partition.

The implementation currently is just:

!self.is_part()
source

pub const fn is_physical(&self) -> bool

Determines if the block-device is considered to be physical. This can be a partition or a disk.

A “physical” disk is one that has a path as in /dev/disk/by-path

The implementation currently is just:

self.path.is_some()
source

pub const fn is_part(&self) -> bool

Returns true if and only if the device is a partition.

The implementation currently is just:

self.partuuid.is_some()